pyibisami.ibis
==============

IBIS related submodules in the *PyIBIS-AMI* package.

file
----

.. automodule:: pyibisami.ibis.file

model
-----

.. automodule:: pyibisami.ibis.model

parser
------

.. automodule:: pyibisami.ibis.parser
